@@ -3,10 +3,12 @@ from typing import Any, Dict, List, Tuple
 
 from django.db import models
 
+from easy.controller.meta_conf import ModelMetaConfig
+
 logger = logging.getLogger(__name__)
 
 
-class DjangoSerializer(object):
+class DjangoSerializer(ModelMetaConfig):
     @staticmethod
     def is_model_instance(data: Any) -> bool:
         return isinstance(data, models.Model)
@@ -79,7 +81,7 @@ class DjangoSerializer(object):
             logger.error(f"serialize_foreign_key error - {obj}", exc_info=exc)
             return {field.name: None}
 
-        if self.get_configuration(obj, "model_recursive", default=False):
+        if self.get_model_recursive(obj):
             return {
                 field.name: self.serialize_model_instance(related_instance, referrers)
             }
@@ -98,7 +100,7 @@ class DjangoSerializer(object):
             for k, v in obj._prefetched_objects_cache.items():  # type: ignore
                 field_name = k if hasattr(obj, k) else k + "_set"
                 if v:
-                    if self.get_configuration(obj, "model_join", default=True):
+                    if self.get_model_join(obj):
                         out[field_name] = self.serialize_queryset(v, referrers + (obj,))
                     else:
                         out[field_name] = [o.pk for o in v]
@@ -108,56 +110,6 @@ class DjangoSerializer(object):
             logger.error(f"serialize_many_relationship error - {obj}", exc_info=exc)
         return out
 
-    @staticmethod
-    def get_configuration(obj: models.Model, _name: str, default: Any = None) -> Any:
-        _value = default if default else None
-        if hasattr(obj, "__Meta"):
-            _value = getattr(obj, "__Meta").get(_name, None)
-        return _value
-
-    def get_model_fields_list(self, obj: models.Model) -> Any:
-        model_fields = self.get_configuration(obj, "model_fields")
-        return model_fields
-
-    def get_model_exclude_list(self, obj: models.Model) -> Any:
-        return self.get_configuration(obj, "model_exclude")
-
-    def get_sensitive_list(self, obj: models.Model) -> Any:
-        return self.get_configuration(obj, "sensitive_fields")
-
-    def get_final_excluded_list(self, obj: models.Model) -> Any:
-        total_excluded_list = []
-        sensitive_list: List = ["password", "token"]
-        excluded_list = []
-
-        sensitive_fields = self.get_sensitive_list(obj)
-        if sensitive_fields:
-            sensitive_list.extend(sensitive_fields)
-        sensitive_list = list(set(sensitive_list))
-
-        excluded_fields = self.get_model_exclude_list(obj)
-        if excluded_fields:
-            excluded_list.extend(excluded_fields)
-        excluded_list = list(set(excluded_list))
-
-        total_excluded_list.extend(sensitive_list)
-        total_excluded_list.extend(excluded_list)
-        return list(set(total_excluded_list))
-
-    def show_field(self, obj: models.Model, field_name: str) -> bool:
-        model_exclude_list = self.get_model_exclude_list(obj)
-        if model_exclude_list:
-            if field_name in self.get_final_excluded_list(obj):
-                return False
-        else:
-            if field_name in self.get_final_excluded_list(obj):
-                return False
-            model_fields_list = self.get_model_fields_list(obj)
-            if model_fields_list != "__all__":
-                if field_name not in model_fields_list:
-                    return False
-        return True
-
     def serialize_value_field(self, obj: models.Model, field: Any) -> Dict[Any, Any]:
         """
         Serializes regular 'jsonable' field (Char, Int, etc.) of Django model instance
